@@ -2,7 +2,9 @@
 
 """Core functionality
 
-Author: Gertjan van den Burg
+Author: G.J.J. van den Burg
+License: See LICENSE file.
+Copyright: 2020, G.J.J. van den Burg
 
 """
 
@@ -11,19 +13,17 @@ import warnings
 import sqlite3
 import shutil
 
-from .exceptions import (
-    DatabaseNotFound,
-    DatabaseVersionNotFound,
-)
-from .models import (
-    Attachment,
-    MMSMessageRecord,
-    Quote,
-    Recipient,
-    RecipientId,
-    SMSMessageRecord,
-    Thread,
-)
+from .exceptions import DatabaseNotFound
+from .exceptions import DatabaseVersionNotFound
+
+from .models import Attachment
+from .models import MMSMessageRecord
+from .models import Quote
+from .models import Recipient
+from .models import RecipientId
+from .models import SMSMessageRecord
+from .models import Thread
+
 from .html import dump_thread
 from .html_colors import get_random_color
 
@@ -40,7 +40,7 @@ def check_backup(backup_dir):
     # We have only ever seen database version 23, so we don't proceed if it's
     # not that. Testing and pull requests welcome.
     version = version_str.split(":")[-1].strip()
-    if not version in ["23", "65", "80"]:
+    if not version in ["23", "65", "80", "89"]:
         warnings.warn(
             f"Warning: Found untested Signal database version: {version}."
         )
@@ -67,7 +67,9 @@ def make_recipient_v23(db, recipient_id):
         isgroup = True
     else:
         qry = db.execute(
-            "SELECT system_display_name FROM recipient_preferences WHERE recipient_ids=?",
+            "SELECT system_display_name "
+            "FROM recipient_preferences "
+            "WHERE recipient_ids=?",
             (recipient_id,),
         )
         label = qry.fetchone()
@@ -76,17 +78,24 @@ def make_recipient_v23(db, recipient_id):
     name = str(recipient_id) if label[0] is None else label[0]
     color = get_color(db, recipient_id)
 
+    phone = str(recipient_id)
     rid = RecipientId(recipient_id)
-    return Recipient(rid, name=name, color=color, isgroup=isgroup)
+    return Recipient(rid, name=name, color=color, isgroup=isgroup, phone=phone)
 
 
 def make_recipient_v80(db, recipient_id):
-    """Create a Recipient instance from a recipient id (db version 65, 80)"""
+    """Create a Recipient instance from a recipient id (db version 65, 80, 89)"""
     qry = db.execute(
-        "SELECT group_id, system_display_name, profile_joined_name, color from recipient where _id=?",
+        "SELECT group_id, "
+        "phone, "
+        "system_display_name, "
+        "profile_joined_name, "
+        "color "
+        "FROM recipient "
+        "WHERE _id=?",
         (recipient_id,),
     )
-    groupid, name, joined_name, color = qry.fetchone()
+    groupid, phone, name, joined_name, color = qry.fetchone()
     if color is None:
         color = get_random_color()
 
@@ -95,29 +104,37 @@ def make_recipient_v80(db, recipient_id):
         qry = db.execute(
             "SELECT title FROM groups WHERE group_id=?", (groupid,)
         )
-        name = qry.fetchone()[0]
+        res = qry.fetchone()
+        if res is not None:
+            name = res[0]
+        else:
+            warnings.warn(
+                f"Group for recipient {recipient_id} is {groupid} which does not exist."
+            )
 
     if name is None:
-        if joined_name is None:
-            name = str(recipient_id)
-        else:
+        if joined_name:
             name = joined_name
+        elif phone:
+            name = phone
+        else:
+            name = ""
 
     rid = RecipientId(recipient_id)
-    return Recipient(rid, name=name, color=color, isgroup=isgroup)
+    return Recipient(rid, name=name, color=color, isgroup=isgroup, phone=phone)
 
 
 def make_recipient(db, recipient_id, version=None):
     if version == "23":
         return make_recipient_v23(db, recipient_id)
-    elif version in ["65", "80"]:
-        return make_recipient_v80(db, recipient_id)
-    else:
-        warnings.warn(
-            f"Untested database version {version}, defaulting to latest known working version."
-        )
+    elif version in ["65", "80", "89"]:
         return make_recipient_v80(db, recipient_id)
 
+    warnings.warn(
+        f"Untested database version {version}, defaulting to latest known working version."
+    )
+    return make_recipient_v80(db, recipient_id)
+
 
 def get_sms_records(db, thread, version=None):
     """ Collect all the SMS records for a given thread """
@@ -158,7 +175,7 @@ def get_attachment_filename(_id, unique_id, backup_dir, thread_dir):
     os.makedirs(target_dir, exist_ok=True)
     target = os.path.join(target_dir, fname)
     shutil.copy(source, target)
-    url = '/'.join(['.', 'attachments', fname])
+    url = "/".join([".", "attachments", fname])
     return url
 
 
@@ -280,7 +297,7 @@ def process_backup(backup_dir, output_dir):
     # Combine the recipient objects and the thread info into Thread objects
     for (_id, _), recipient in zip(threads, recipients):
         t = Thread(_id=_id, recipient=recipient)
-        thread_dir = os.path.join(output_dir, t.name.replace(" ", "_"))
+        thread_dir = os.path.join(output_dir, t.sanename)
         populate_thread(
             db, t, recipients, backup_dir, thread_dir, version=db_version
         )
