@@ -2,7 +2,9 @@
 
 """Code for writing out the HTML
 
-Author: Gertjan van den Burg
+Author: G.J.J. van den Burg
+License: See LICENSE file.
+Copyright: 2020, G.J.J. van den Burg
 
 """
 
@@ -10,18 +12,18 @@ import os
 import datetime as dt
 
 from emoji import emoji_lis as emoji_list
-from jinja2 import Environment, PackageLoader, select_autoescape
+from jinja2 import Environment
+from jinja2 import PackageLoader
+from jinja2 import select_autoescape
 
-from .models import MMSMessageRecord
-from .types import (
-    get_named_message_type,
-    is_inbox_type,
-    is_incoming_call,
-    is_joined_type,
-    is_missed_call,
-    is_outgoing_call,
-)
 from .html_colors import COLORMAP
+from .models import MMSMessageRecord
+from .types import get_named_message_type
+from .types import is_inbox_type
+from .types import is_incoming_call
+from .types import is_joined_type
+from .types import is_missed_call
+from .types import is_outgoing_call
 
 
 def is_all_emoji(body):
@@ -180,8 +182,11 @@ def dump_thread(thread, output_dir):
 
     os.makedirs(output_dir, exist_ok=True)
 
+    # Use phone number to distinguish threads from the same contact,
+    # except for groups, which do not have a phone number.
     filename = os.path.join(
-        output_dir, thread.name.replace(" ", "_") + ".html"
+        output_dir,
+        f"{thread.sanename if is_group else thread.sanephone}.html",
     )
     with open(filename, "w", encoding="utf-8") as fp:
         fp.write(html)
